import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect/index')
      }
    ]
  },
  // 登录
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  // 首页显示的页面
  {
    path: '/',
    component: Layout
    // redirect: '/supplier/list'
  },
  // 供应商管理页面
  {
    path: '/supplier',
    component: Layout,
    alwaysShow: true,
    name: 'Supplier',
    redirect: '/supplier/list',
    meta: { title: '供应商管理', icon: 'peoples' },
    children: [
      // admin
      {
        path: 'list',
        component: () => import('@/views/supplier/user/index'),
        name: 'SupplierList',
        meta: { title: '供应商列表', affix: true }
      },
      {
        hidden: true,
        path: 'add',
        component: () => import('@/views/supplier/user/add'),
        name: 'SupplierAdd',
        meta: { title: '添加供应商' }
      },
      {
        hidden: true,
        path: 'edit',
        component: () => import('@/views/supplier/user/edit'),
        name: 'SupplierAdd',
        meta: { title: '修改供应商' }
      }
    ]
  },
  // 授权管理页面
  {
    path: '/auth',
    component: Layout,
    alwaysShow: true,
    redirect: '/auth/list',
    name: 'Auth',
    meta: { title: '授权管理', icon: 'el-icon-s-promotion' },
    children: [
      {
        path: 'list',
        component: () => import('@/views/supplier/auth/index'),
        name: 'AuthList',
        meta: { title: '授权列表' }
      }
    ]
  },
  // 商品管理
  {
    path: '/product',
    component: Layout,
    alwaysShow: true,
    redirect: '/product/list',
    name: 'Auth',
    meta: { title: '商品管理', icon: 'el-icon-s-shop' },
    children: [
      {
        path: 'list',
        component: () => import('@/views/supplier/product/index'),
        name: 'Product',
        meta: { title: '商品列表' }
      },
      {
        hidden: true,
        path: 'add',
        component: () => import('@/views/supplier/product/add'),
        name: 'AddProduct',
        meta: { title: '添加商品' }
      },
      {
        hidden: true,
        path: 'edit',
        component: () => import('@/views/supplier/product/edit'),
        name: 'EditProduct',
        meta: { title: '修改商品' }
      }
    ]
  }
]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
  })

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
